# -*- coding: utf-8 -*-

from .metbit import opls_da, pca
from .utility import *
from .lazy_opls_da import lazy_opls_da
from .spec_norm import *
from .peak_processe import peak_chops
from .STOCSY import STOCSY
from .ui_stocsy import STOCSY_app
from .ui_picky_peak import pickie_peak



__author__ = 'aeiwz'
__email__ = 'theerayut_aeiw_123@hotmail.com'



